###############################################################################
#
# Variables set by the module:
# OAINKUBATOTRLIB_FOUND    - TRUE if all components are found
# OAINKUBATOR_INCLUDE_DIR  - Location of the include directory
# OAINKUBATOR_LIBRARY_DIR  - Location of the library directory
# OAINKUBATOR_LIBRARY      - libinkubator (needed for linking)
#
# Example Usages:
#
# FIND_PACKAGE(OAInkubatorLib)
#
###############################################################################

# Handles standard arguments
include(FindPackageHandleStandardArgs)

# Search for the file OAINKUBATORLIB_ROOT in the search path
find_path(
  OAINKUBATORLIB_ROOT_DIR OAINKUBATORLIB_ROOT
  HINTS
    /opt/OAInkubatorLib
    /usr/local/OAInkubatorLib
    /usr/OAInkubatorLib
    ENV OAINKUBATOR_ROOT
)

# find the include directories.
find_path(
  OAINKUBATOR_INCLUDE_DIR 
  inkubator.hpp
  PATHS ${OAINKUBATORLIB_ROOT_DIR}/include
 )

# Find the library
find_library(
  OAINKUBATOR_LIBRARY
  NAMES inkubator
  PATHS ${OAINKUBATORLIB_ROOT_DIR}/lib
)

# Check that all files and directories were properly found
find_package_handle_standard_args (
  OAINKUBATOTRLIB 
  DEFAULT_MSG
  OAINKUBATORLIB_ROOT_DIR
  OAINKUBATOR_INCLUDE_DIR
  OAINKUBATOR_LIBRARY 
)

get_filename_component(
  OAINKUBATOR_LIBRARY_DIR 
  ${OAINKUBATOR_LIBRARY} 
  PATH
)

mark_as_advanced(
  OAINKUBATOR_INCLUDE_DIR
  OAINKUBATOR_LIBRARY_DIR
  OAINKUBATOR_LIBRARY
)
